@@ -1,7 +1,7 @@
 fulllikepower= function(dat,I,phi,smlgamma){
   # this returns log-likelihood of data
-  #source('BARDMallowslikepower.R')
-  output=lapply(seq_len(ncol(dat)), function(i) BARDMallowslikepower(dat[,i],I,phi,smlgamma[i]))
+  #source('PAMAlike.R')
+  output=lapply(seq_len(ncol(dat)), function(i) PAMAlike(dat[,i],I,phi,smlgamma[i]))
   a=unlist(output)
   return(sum(a))# log likelihood
 }
